/*
** Module   : SaxAttributesImpl
** Abstract : SAX attributes specific features implementation.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20130208 Created initial version. Implementation is limited to the stubs to get the
**                  converted java code compiled. 
*/

package com.goldencode.p2j.xml;

import com.goldencode.p2j.util.*;

/**
 * Interface describing SAX-Attributes specific features of the SAX objects.
 */
public class SaxAttributesImpl
extends SaxEntityImpl
implements SaxAttributes
{
   /**
    * Gets the numbers of the enties in the attributes object.
    * 
    * @return   The integer value of the num-items attribute.
    */
   public integer getNumItems()
   {
      // TODO:
      return new integer();
   }
   
   /**
    * Gets the value of the atribute with given index.
    * 
    * @param    index
    *           The 1-based index of the attribute to get.
    * 
    * @return   The character value of the attribute with given number.
    */
   public character getValueByIndex(double index)
   {
      return getValueByIndex(new integer(index));
   }

   /**
    * Gets the value of the atribute with given index.
    * 
    * @param    index
    *           The 1-based index of the attribute to get.
    * 
    * @return   The character value of the attribute with given number.
    */
   public character getValueByIndex(NumberType index)
   {
      // TODO:
      return new character();
   }

   /**
    * Copies SAX attributes form source provided to the current SAX-Attributes object.
    * 
    * @param    handle
    *           The handle of the SAX-Attribute object to be used as source.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical copySaxAttributes(handle handle)
   {
      // TODO:
      return new logical(true);
   }
   
   /**
    * Gets the 1-based index of the attribute with given namespace name.
    * 
    * @param    uri
    *           The namespace URI or empty string if none.
    * @param    localname
    *           The local(unqualified) name of the attribute.
    * 
    * @return   The integer value of the given attribute index.
    */
   public integer getIndexByNamespaceName(Text uri, Text localname)
   {
      // TODO:
      return new integer();
   }
   
   /**
    * Gets the 1-based index of the attribute with given namespace name.
    * 
    * @param    uri
    *           The namespace URI or empty string if none.
    * @param    localname
    *           The local(unqualified) name of the attribute.
    * 
    * @return   The integer value of the given attribute index.
    */
   public integer getIndexByNamespaceName(String uri, Text localname)
   {
      return getIndexByNamespaceName(new character(uri), localname);
   }
   
   /**
    * Gets the 1-based index of the attribute with given namespace name.
    * 
    * @param    uri
    *           The namespace URI or empty string if none.
    * @param    localname
    *           The local(unqualified) name of the attribute.
    * 
    * @return   The integer value of the given attribute index.
    */
   public integer getIndexByNamespaceName(Text uri, String localname)
   {
      return getIndexByNamespaceName(uri, new character(localname));
   }
   
   /**
    * Gets the 1-based index of the attribute with given namespace name.
    * 
    * @param    uri
    *           The namespace URI or empty string if none.
    * @param    localname
    *           The local(unqualified) name of the attribute.
    * 
    * @return   The integer value of the given attribute index.
    */
   public integer getIndexByNamespaceName(String uri, String localname)
   {
      return getIndexByNamespaceName(new character(uri), new character(localname));
   }

   /**
    * Gets the 1-based index of the attribute with given XML qualified name.
    * 
    * @param    qname
    *           The XML qualified name of the attribute to get the index.
    * 
    * @return   The integer value of the given attribute index.
    */
   public integer getIndexByQname(Text qname)
   {
      // TODO:
      return new integer();
   }
   
   /**
    * Gets the 1-based index of the attribute with given XML qualified name.
    * 
    * @param    qname
    *           The XML qualified name of the attribute to get the index.
    * 
    * @return   The integer value of the given attribute index.
    */
   public integer getIndexByQname(String qname)
   {
      return getIndexByQname(new character(qname));
   }

   /**
    * Gets the unqualified local name of the current attribute object by the given 1-based index.
    * 
    * @param    index
    *           The 1-based index of the attribute name to get.
    * 
    * @return   The character value of the attribute local name with given number.
    */
   public character getLocalnameByIndex(double index)
   {
      return getLocalnameByIndex(new integer(index));
   }

   /**
    * Gets the unqualified local name of the current attribute object by the given 1-based index.
    * 
    * @param    index
    *           The 1-based index of the attribute name to get.
    * 
    * @return   The character value of the attribute local name with given number.
    */
   public character getLocalnameByIndex(NumberType index)
   {
      // TODO:
      return new character();
   }

   /**
    * Gets the qualified name of the current attribute object by the given 1-based index.
    * 
    * @param    index
    *           The 1-based index of the attribute name to get.
    * 
    * @return   The character value of the attribute qualified name with given number.
    */
   public character getQnameByIndex(double index)
   {
      return getQnameByIndex(new integer(index));
   }

   /**
    * Gets the qualified local name of the current attribute object by the given 1-based index.
    * 
    * @param    index
    *           The 1-based index of the attribute name to get.
    * 
    * @return   The character value of the attribute qualified name with given number.
    */
   public character getQnameByIndex(NumberType index)
   {
      // TODO:
      return new character();
   }

   /**
    * Gets the type of the current attribute object by the given 1-based index.
    * 
    * @param    index
    *           The 1-based index of the attribute type to get.
    * 
    * @return   The character value of the attribute type with given number.
    */
   public character getTypeByIndex(double index)
   {
      return getTypeByIndex(new integer(index));
   }

   /**
    * Gets the type of the current attribute object by the given 1-based index.
    * 
    * @param    index
    *           The 1-based index of the attribute type to get.
    * 
    * @return   The character value of the attribute type with given number.
    */
   public character getTypeByIndex(NumberType index)
   {
      // TODO:
      return new character();
   }

   /**
    * Gets the type of the attribute with given namespace name.
    * 
    * @param    uri
    *           The namespace URI or empty string if none.
    * @param    localname
    *           The local(unqualified) name of the attribute.
    * 
    * @return   The character value of the given attribute type.
    */
   public character getTypeByNamespaceName(Text uri, Text localname)
   {
      // TODO:
      return new character();
   }
   
   /**
    * Gets the type of the attribute with given namespace name.
    * 
    * @param    uri
    *           The namespace URI or empty string if none.
    * @param    localname
    *           The local(unqualified) name of the attribute.
    * 
    * @return   The character value of the given attribute type.
    */
   public character getTypeByNamespaceName(String uri, Text localname)
   {
      return getTypeByNamespaceName(new character(uri), localname);
   }
   
   /**
    * Gets the type of the attribute with given namespace name.
    * 
    * @param    uri
    *           The namespace URI or empty string if none.
    * @param    localname
    *           The local(unqualified) name of the attribute.
    * 
    * @return   The character value of the given attribute type.
    */
   public character getTypeByNamespaceName(Text uri, String localname)
   {
      return getTypeByNamespaceName(uri, new character(localname));
   }
   
   /**
    * Gets the type of the attribute with given namespace name.
    * 
    * @param    uri
    *           The namespace URI or empty string if none.
    * @param    localname
    *           The local(unqualified) name of the attribute.
    * 
    * @return   The character value of the given attribute type.
    */
   public character getTypeByNamespaceName(String uri, String localname)
   {
      return getTypeByNamespaceName(new character(uri), new character(localname));
   }

   /**
    * Gets the type of the attribute with given XML qualified name.
    * 
    * @param    qname
    *           The XML qualified name of the attribute to get the type.
    * 
    * @return   The character value of the given attribute type.
    */
   public character getTypeByQname(character qname)
   {
      // TODO:
      return new character();
   }
   
   /**
    * Gets the type of the attribute with given XML qualified name.
    * 
    * @param    qname
    *           The XML qualified name of the attribute to get the type.
    * 
    * @return   The character value of the given attribute type.
    */
   public character getTypeByQname(String qname)
   {
      return getTypeByQname(new character(qname));
   }

   /**
    * Gets the namespace URI of the current attribute object by the given 1-based index.
    * 
    * @param    index
    *           The 1-based index of the namespace URI to get.
    * 
    * @return   The character value of the namespace URI with given number.
    */
   public character getUriByIndex(double index)
   {
      return getUriByIndex(new integer(index));
   }

   /**
    * Gets the namespace URI of the current attribute object by the given 1-based index.
    * 
    * @param    index
    *           The 1-based index of the namespace URI to get.
    * 
    * @return   The character value of the namespace URI with given number.
    */
   public character getUriByIndex(NumberType index)
   {
      // TODO:
      return new character();
   }

   /**
    * Gets the value of the attribute with given namespace name.
    * 
    * @param    uri
    *           The namespace URI or empty string if none.
    * @param    localname
    *           The local(unqualified) name of the attribute.
    * 
    * @return   The character value of the given attribute.
    */
   public character getValueByNamespaceName(Text uri, Text localname)
   {
      // TODO:
      return new character();
   }
   
   /**
    * Gets the value of the attribute with given namespace name.
    * 
    * @param    uri
    *           The namespace URI or empty string if none.
    * @param    localname
    *           The local(unqualified) name of the attribute.
    * 
    * @return   The character value of the given attribute.
    */
   public character getValueByNamespaceName(String uri, Text localname)
   {
      return getValueByNamespaceName(new character(uri), localname);
   }
   
   /**
    * Gets the value of the attribute with given namespace name.
    * 
    * @param    uri
    *           The namespace URI or empty string if none.
    * @param    localname
    *           The local(unqualified) name of the attribute.
    * 
    * @return   The character value of the given attribute.
    */
   public character getValueByNamespaceName(Text uri, String localname)
   {
      return getValueByNamespaceName(uri, new character(localname));
   }
   
   /**
    * Gets the value of the attribute with given namespace name.
    * 
    * @param    uri
    *           The namespace URI or empty string if none.
    * @param    localname
    *           The local(unqualified) name of the attribute.
    * 
    * @return   The character value of the given attribute.
    */
   public character getValueByNamespaceName(String uri, String localname)
   {
      return getValueByNamespaceName(new character(uri), new character(localname));
   }

   /**
    * Gets the value of the attribute with given XML qualified name.
    * 
    * @param    qname
    *           The XML qualified name of the attribute to get the value.
    * 
    * @return   The character value of the given attribute.
    */
   public character getValueByQname(character qname)
   {
      // TODO:
      return new character();
   }
   
   /**
    * Gets the value of the attribute with given XML qualified name.
    * 
    * @param    qname
    *           The XML qualified name of the attribute to get the value.
    * 
    * @return   The character value of the given attribute.
    */
   public character getValueByQname(String qname)
   {
      return getValueByQname(new character(qname));
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(character name, character value)
   {
      return updateAttribute(name, new character(value), new character());
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(character name, String value)
   {
      return updateAttribute(name, new character(value), new character());
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * @param    uri
    *           The URI of the attribute to update.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(character name, String value, character uri)
   {
      return updateAttribute(name, new character(value), uri);
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * @param    uri
    *           The URI of the attribute to update.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(character name, character value, String uri)
   {
      return updateAttribute(name, value, new character(uri));
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * @param    uri
    *           The URI of the attribute to update.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(character name, String value, String uri)
   {
      return updateAttribute(name, new character(value), new character(uri));
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(String name, character value)
   {
      return updateAttribute(new character(name), new character(value), new character());
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(String name, String value)
   {
      return updateAttribute(new character(name), new character(value), new character());
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * @param    uri
    *           The URI of the attribute to update.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(String name, String value, character uri)
   {
      return updateAttribute(new character(name), new character(value), uri);
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * @param    uri
    *           The URI of the attribute to update.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(String name, character value, String uri)
   {
      return updateAttribute(new character(name), value, new character(uri));
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * @param    uri
    *           The URI of the attribute to update.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(String name, String value, String uri)
   {
      return updateAttribute(new character(name), new character(value),
                             new character(uri));
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * @param    uri
    *           The URI of the attribute to update.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(String name, character value, character uri)
   {
      return updateAttribute(new character(name), value, uri);
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * @param    uri
    *           The URI of the attribute to update.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(character name, character value, character uri)
   {
      // TODO:
      return new logical(true);
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    index
    *           The 1-based position index of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(NumberType index, character value)
   {
      return updateAttribute(index, new character(value), new character());
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    index
    *           The 1-based position index of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(NumberType index, String value)
   {
      return updateAttribute(index, new character(value), new character());
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    index
    *           The 1-based position index of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * @param    uri
    *           The URI of the attribute to update.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(NumberType index, String value, character uri)
   {
      return updateAttribute(index, new character(value), uri);
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    index
    *           The 1-based position index of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * @param    uri
    *           The URI of the attribute to update.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(NumberType index, character value, String uri)
   {
      return updateAttribute(index, value, new character(uri));
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    index
    *           The 1-based position index of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * @param    uri
    *           The URI of the attribute to update.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(NumberType index, String value, String uri)
   {
      return updateAttribute(index, new character(value), new character(uri));
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    index
    *           The 1-based position index of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(double index, character value)
   {
      return updateAttribute(new integer(index), new character(value), new character());
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    index
    *           The 1-based position index of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(double index, String value)
   {
      return updateAttribute(new integer(index), new character(value), new character());
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    index
    *           The 1-based position index of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * @param    uri
    *           The URI of the attribute to update.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(double index, String value, character uri)
   {
      return updateAttribute(new integer(index), new character(value), uri);
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    index
    *           The 1-based position index of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * @param    uri
    *           The URI of the attribute to update.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(double index, character value, String uri)
   {
      return updateAttribute(new integer(index), value, new character(uri));
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    index
    *           The 1-based position index of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * @param    uri
    *           The URI of the attribute to update.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(double index, String value, String uri)
   {
      return updateAttribute(new integer(index), new character(value),
                             new character(uri));
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    index
    *           The 1-based position index of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * @param    uri
    *           The URI of the attribute to update.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(double index, character value, character uri)
   {
      return updateAttribute(new integer(index), value, uri);
   }

   /**
    * Updates the specified attribute.
    * 
    * @param    index
    *           The 1-based position index of the attribute to update.
    * @param    value
    *           The new value of the updated attribute.
    * @param    uri
    *           The URI of the attribute to update.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical updateAttribute(NumberType index, character value, character uri)
   {
      // TODO:
      return new logical(true);
   }
}
